package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````*&``````````0```````
M`,'(``````!``#@`"0!``!L`&@````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*RP````````K+``
M```````0``````$````&````````NZ````````"[H````````+N@````````
M!.@````````%$````````!```````@````8```````"[L````````+NP````
M````N[`````````"(`````````(@``````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````I7````````"E<````````*5P`````````.P`````````[```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````+N@````````NZ``````
M``"[H`````````1@````````!&```````````2]L:6(O;&0V-"YS;RXQ````
M```$````%`````-'3E4`G[V#Z..@^$/0P#O,LO5]]_,KWW$````$````$```
M``%'3E4```````````,````"````````````````````0P````````!>````
M``````````````````````````!8````````````````````,``````````Q
M````````````````````40```````````````````"L`````````50``````
M```\`````````"D`````````5P````````!#`````````#(`````````/0``
M````````````````````````````.0``````````````````````````````
M.``````````8`````````$\`````````+``````````S`````````!<`````
M````4@````````!0````````````````````````````````````````````
M````````*@`````````>`````````"8```````````````````!.````````
M`$T```````````````````!`````````````````````/P````````!;````
M````````````````)``````````$````````````````````2@``````````
M``````````8```````````````````!:`````````#L`````````&@``````
M``!"````````````````````20````````!6`````````!D`````````-P``
M```````,`````````$0`````````/@`````````N`````````$8`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````"P`````````"````````
M````````````!0````````!,````````````````````1P`````````3````
M`````%P````````````````````````````````````````````````````(
M````````````````````#P````````!3``````````T`````````!P``````
M```<`````````!0````````````````````.````````````````````)0``
M````````````````````````````5``````````G````````````````````
M"0```````````````````"$`````````"@``````````````````````````
M````'P```````````````````"@`````````$``````````V`````````$L`
M```````````````````T`````````",`````````%0`````````2````````
M`"\`````````'0`````````@`````````$4`````````````````````````
M````````````````+0````````!=```````````````````````````````B
M``````````````````````````````!9`````````!$`````````````````
M```6````````````````````.@````````!!````````````````````2```
M```````;`````````#4`````````````````````````````````````````
M`````````````````````````````````P```!$```!$````!`````B$!$`%
M`!`0((0`AH`$``(H"`0@"0(`B8((`@"Z01"`B`````````!$````1P```$H`
M``!+````4P```%0```!5`````````%<```!8````60```%H```!;````70``
M````````']_%;BU'WLY\FG]KMIO%+GS49-0.Y/\A'%AQV0'&1^)OBP&RP.-+
MK(?7^D(L/^7"?)+CNF!LH?J;PT^9UD,):V;,KV?LU45"TW`'B>W;8C/,)8P5
M"Y<Z#9N<J7\*`J?@4)X::TG[X*,`````````````````````````````````
M``````````,```P````````>H``````````````#=A(`````````````````
M```````````"IA(`````````````````````````````C!$`````````````
M```````````````!PQ(````````````````````````````"#1(`````````
M```````````````````"C1(`````````````````````````````TA(`````
M```````````````````````"21(````````````````````````````!RA(`
M`````````````````````````````2`````````````````````````````"
MAA(`````````````````````````````9Q(`````````````````````````
M```!MA(`````````````````````````````VQ(`````````````````````
M```````"V!(````````````````````````````!A1(`````````````````
M```````````!_1(````````````````````````````!*1(`````````````
M```````````````!:A(`````````````````````````````E!(`````````
M````````````````````$"`````````````````````````````"OA(`````
M```````````````````````!(!(`````````````````````````````BA$`
M```````````````````````````!-Q(`````````````````````````````
M+"``````````````````````````````G1(`````````````````````````
M```"L!(````````````````````````````!6Q(`````````````````````
M````````X18`````````````````````````````]!(`````````````````
M```````````!?A(````````````````````````````"7!(`````````````
M```````````````!#Q(````````````````````````````"R1(`````````
M````````````````````LQ(`````````````````````````````6"(`````
M```````````````````````!UQ(````````````````````````````!L1(`
M```````````````````````````!/A(````````````````````````````!
MT1(````````````````````````````!8Q(`````````````````````````
M```!HA(````````````````````````````"F!(`````````````````````
M```````"+A(`````````````````````````````>1(`````````````````
M```````````!=Q(````````````````````````````!Z!(`````````````
M````````````````G!(`````````````````````````````RQ(`````````
M```````````````````"&1(````````````````````````````!OA(`````
M```````````````````````">A(````````````````````````````"JQ(`
M```````````````````````````!]A(````````````````````````````"
M;1$````````````````````````````!C!(`````````````````````````
M````I!(`````````````````````````````O1(`````````````````````
M```````!!!(````````````````````````````!31(`````````````````
M````````````JQ(````````````````````````````".A(`````````````
M````````````````1A(````````````````````````````!E!(`````````
M```````````````````!FQ$````````````````````````````#?Q(```X`
M``````!?0`````````#2```#U!(```X```````!6``````````;^````4Q(`
M``X````````EX`````````*````"]A(```X```````!(,``````````&```#
M%!(```X```````!=``````````(^```#^A(```X```````!(.`````````)H
M```#NA```!@```````#`B``````````````#!Q(```X```````!*H```````
M```T```#*A(```X```````!1P`````````!V```#BQ$``!````````!DX```
M```````$```#IQ(```X```````!@B`````````'````#LA(```X```````!&
M^``````````X```#SQ```!@```````#`L``````````````#Z!(```X`````
M``!4\`````````$.```$$1(```X```````!2.`````````!X```#FA```!<`
M``````#````````````````#3A(```X```````!*V`````````%4```#X1``
M`!<```````#`B``````````````$!Q$``!<```````#`@``````````(```#
MH!(```X````````H8``````````````#QA(```X```````!@&`````````!L
M```#G"```!<```````#````````````````#9!(```X```````!4P```````
M```L```#.!(```X```````!',`````````#^```#6A(```X```````!B2```
M``````)4```$&1(```X```````!,,`````````6,`%]?9VUO;E]S=&%R=%]?
M`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#
M;&]N951A8FQE`%]?;&EB8U]S=&%R=%]M86EN`%]?8WAA7V9I;F%L:7IE`%]?
M<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V9A:6P`7U]E;G9I<F]N`'-T
M<FYC;7``;'-T870V-`!A8V-E<W,`;W!E;F1I<@!R96%D9&ER-C0`7U]S<')I
M;G1F7V-H:P!U;FQI;FL`8VQO<V5D:7(`<FUD:7(`4$Q?8W5R<F5N=%]C;VYT
M97AT`&)O;W1?1'EN84QO861E<@!097)L7VYE=UA3`%!E<FQ?;F5W6%-?9FQA
M9W,`<F5A9&QI;FL`4&5R;%]S=E]S971P=@!M96UC:'(`4&5R;%]S=E]S971P
M=FX`7U]M96UM;W9E7V-H:P!R96%L;&]C`&=E='!I9`!?7VUE;6-P>5]C:&L`
M<W1R8VAR`'-T<F1U<`!S=')T;VL`<W1R<F-H<@!M96UC<'D`<W1D97)R`%]?
M=F9P<FEN=&9?8VAK`&5X:70`;'-E96LV-`!R96%D`&=E='5I9`!S=')S='(`
M;6MD:7(`7U]E<G)N;U]L;V-A=&EO;@!?7V9P<FEN=&9?8VAK`&]P96XV-`!0
M97)L7V=V7V9E=&-H<'8`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E
M>'0`4&5R;%]M9U]S970`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?=6YL
M;V-K`%!E<FQ?871F;W)K7VQO8VL`4$Q?9&]?=6YD=6UP`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7W!A<G-E`'!E<FQ?9&5S=')U8W0`<&5R;%]F<F5E`%!E
M<FQ?<WES7W1E<FT`<&5R;%]A;&QO8P!P97)L7V-O;G-T<G5C=`!P97)L7W)U
M;@!L:6)P97)L+G-O`&QI8F,N<V\N-@!P87)?8W5R<F5N=%]E>&5C`'!A<E]B
M87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P
M87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E
M=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])3U]S=&1I
M;E]U<V5D`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`7U]B<W-?
M<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S
M971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P
M87)?:6YI=%]E;G8`1TQ)0D-?,BXS-`!'3$E"0U\R+C0`1TQ)0D-?,BXS,P!'
M3$E"0U\R+C,N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C(`+W5S<B]L:6(O<&5R
M;#4O-2XS."XP+W,S.3!X+6QI;G5X+71H<F5A9"UM=6QT:2]#3U)%````````
M`@`!``(``@`!``$``@`!``(``0`"``,``@`"``$``@`!``$`!``"``$``0`"
M``(``@`!``4``0`"``$``0`"``$``0`!``(``@`"``(``0`"``(`!@`!``$`
M!@`"``8`!0`"``$``@`!``(``@`!``(``@`&``$`!``"``$`!P`"``(``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$`!@```NP````0``````:6D;0````'```$)@```!`-:6D4````!@``
M!#$````0!I:1LP````4```0[````$`EI&70````$```$1@```!`):1ER````
M`P``!%(````0#6EI$@````(```1>`````````````+N@``````````P`````
M```I8````````+NH``````````P````````I&````````+_X``````````P`
M```````EX````````,`(``````````P```````#`"````````,`@````````
M``P```````"E4````````,`H``````````P```````!E/````````,`X````
M``````P```````!EW````````,!```````````P```````!EX````````,!(
M``````````P```````"E1````````,!0``````````P```````!E0@``````
M`,!8``````````P```````"E3````````,!H``````````P```````"E-```
M`````,!P``````````P```````"E.@```````,"```````````P```````!G
MQ````````+^@````!`````H``````````````````+^H````"0````H`````
M`````````````+^P````"P````H``````````````````+^X````%@````H`
M`````````````````+_`````&P````H``````````````````+_(````'P``
M`#@``````````````````+_0````(`````H``````````````````+_8````
M(@````H``````````````````+_@````)@````H``````````````````+_H
M````.0````H``````````````````+_P````0P````H`````````````````
M`+WH`````@````L``````````````````+WP`````P````L`````````````
M`````+WX````!0````L``````````````````+X`````!@````L`````````
M`````````+X(````!P````L``````````````````+X0````"`````L`````
M`````````````+X8````"@````L``````````````````+X@````#`````L`
M`````````````````+XH````#0````L``````````````````+XP````#@``
M``L``````````````````+XX````#P````L``````````````````+Y`````
M$`````L``````````````````+Y(````$0````L``````````````````+Y0
M````$@````L``````````````````+Y8````$P````L`````````````````
M`+Y@````%`````L``````````````````+YH````%0````L`````````````
M`````+YP````%P````L``````````````````+YX````&`````L`````````
M`````````+Z`````&@````L``````````````````+Z(````'`````L`````
M`````````````+Z0````'0````L``````````````````+Z8````'@````L`
M`````````````````+Z@````(0````L``````````````````+ZH````(P``
M``L``````````````````+ZP````)`````L``````````````````+ZX````
M)0````L``````````````````+[`````)@````L``````````````````+[(
M````)P````L``````````````````+[0````*`````L`````````````````
M`+[8````*0````L``````````````````+[@````*@````L`````````````
M`````+[H````*P````L``````````````````+[P````+`````L`````````
M`````````+[X````+0````L``````````````````+\`````+@````L`````
M`````````````+\(````+P````L``````````````````+\0````,`````L`
M`````````````````+\8````,0````L``````````````````+\@````,@``
M``L``````````````````+\H````,P````L``````````````````+\P````
M-`````L``````````````````+\X````-0````L``````````````````+]`
M````-@````L``````````````````+](````-P````L`````````````````
M`+]0````.`````L``````````````````+]8````.@````L`````````````
M`````+]@````.P````L``````````````````+]H````/`````L`````````
M`````````+]P````/0````L``````````````````+]X````/@````L`````
M`````````````+^`````/P````L``````````````````+^(````0`````L`
M`````````````````+^0````00````L``````````````````+^8````0@``
M``L``````````.MO\#``)+D$`!^G^_]@XQ#P```DP,```$^.P!```%![XQ`0
M```$N0(`$:>$``,-X>-`\1``!.MO\-``!`?T!P?C$/`X`"3`$```3W72!_`P
M$`CC$!`0``0'\0<`!P`'`,`0``!/=.,0$```!`?Q#1#C$!`,`!3`]/___^4`
M````P!```$]HXQ`0```$!_$-$.,0$`P`%,#T____U0```!C`$```3USC$!``
M``0'\0T0XQ`0#``4P/3____%````,,`0``!/4.,0$```!`?Q#1#C$!`,`!3`
M]/___[4```!(P!```$]$XQ`0```$!_$-$.,0$`P`%,#T____I0```&#`$```
M3SCC$!````0'\0T0XQ`0#``4P/3___^5````>,`0``!/+.,0$```!`?Q#1#C
M$!`,`!3`]/___X4```"0P!```$\@XQ`0```$!_$-$.,0$`P`%,#T____=0``
M`*C`$```3Q3C$!````0'\0T0XQ`0#``4P/3___]E````P,`0``!/".,0$```
M!`?Q#1#C$!`,`!3`]/___U4```#8P!```$[\XQ`0```$!_$-$.,0$`P`%,#T
M____10```/#`$```3O#C$!````0'\0T0XQ`0#``4P/3___\U```!",`0``!.
MY.,0$```!`?Q#1#C$!`,`!3`]/___R4```$@P!```$[8XQ`0```$!_$-$.,0
M$`P`%,#T____%0```3C`$```3LSC$!````0'\0T0XQ`0#``4P/3___\%```!
M4,`0``!.P.,0$```!`?Q#1#C$!`,`!3`]/___O4```%HP!```$ZTXQ`0```$
M!_$-$.,0$`P`%,#T___^Y0```8#`$```3JCC$!````0'\0T0XQ`0#``4P/3_
M__[5```!F,`0``!.G.,0$```!`?Q#1#C$!`,`!3`]/___L4```&PP!```$Z0
MXQ`0```$!_$-$.,0$`P`%,#T___^M0```<C`$```3H3C$!````0'\0T0XQ`0
M#``4P/3___ZE```!X,`0``!.>.,0$```!`?Q#1#C$!`,`!3`]/___I4```'X
MP!```$YLXQ`0```$!_$-$.,0$`P`%,#T___^A0```A#`$```3F#C$!````0'
M\0T0XQ`0#``4P/3___YU```"*,`0``!.5.,0$```!`?Q#1#C$!`,`!3`]/__
M_F4```)`P!```$Y(XQ`0```$!_$-$.,0$`P`%,#T___^50```EC`$```3CSC
M$!````0'\0T0XQ`0#``4P/3___Y%```"<,`0``!.,.,0$```!`?Q#1#C$!`,
M`!3`]/___C4```*(P!```$XDXQ`0```$!_$-$.,0$`P`%,#T___^)0```J#`
M$```3ACC$!````0'\0T0XQ`0#``4P/3___X5```"N,`0``!.#.,0$```!`?Q
M#1#C$!`,`!3`]/___@4```+0P!```$X`XQ`0```$!_$-$.,0$`P`%,#T___]
M]0```NC`$```3?3C$!````0'\0T0XQ`0#``4P/3___WE```#`,`0``!-Z.,0
M$```!`?Q#1#C$!`,`!3`]/___=4```,8P!```$W<XQ`0```$!_$-$.,0$`P`
M%,#T___]Q0```S#`$```3=#C$!````0'\0T0XQ`0#``4P/3___VU```#2,`0
M``!-Q.,0$```!`?Q#1#C$!`,`!3`]/___:4```-@P!```$VXXQ`0```$!_$-
M$.,0$`P`%,#T___]E0```WC`$```3:SC$!````0'\0T0XQ`0#``4P/3___V%
M```#D,`0``!-H.,0$```!`?Q#1#C$!`,`!3`]/___74```.HP!```$V4XQ`0
M```$!_$-$.,0$`P`%,#T___]90```\#`$```38CC$!````0'\0T0XQ`0#``4
MP/3___U5```#V,`0``!-?.,0$```!`?Q#1#C$!`,`!3`]/___44```/PP!``
M`$UPXQ`0```$!_$-$.,0$`P`%,#T___]-0``!`C`$```363C$!````0'\0T0
MXQ`0#``4P/3___TE```$(,`0``!-6.,0$```!`?Q#1#C$!`,`!3`]/___14`
M``0XP!```$U,XQ`0```$!_$-$.,0$`P`%,#T___]!0``!%#`$```34#C$!``
M``0'\0T0XQ`0#``4P/3___SU```$:,`0``!--.,0$```!`?Q#1#C$!`,`!3`
M]/___.4```2`P!```$THXQ`0```$!_$-$.,0$`P`%,#T___\U0``!)C`$```
M31SC$!````0'\0T0XQ`0#``4P/3___S%```$L,`0``!-$.,0$```!`?Q#1#C
M$!`,`!3`]/___+4```3(P!```$T$XQ`0```$!_$-$.,0$`P`%,#T___\I0``
M!.#`$```3/CC$!````0'\0T0XQ`0#``4P/3___R5```$^,`0``!,[.,0$```
M!`?Q#1#C$!`,`!3`]/___(4```40ZV_P,``DX_#_./]QXS#PJ``DXT#PH``D
M4"#PM$%`\*!!,/"H02#PM+)/`+#KNP`@``VR3P"QT@?PP+`HP.7___^RQ$@`
M`$S#Q"@``$S8N00`-,#E```?-\08``!,V)4`$`"GA`"VP#```$S!XU`P```$
M6*#PM.R:``0`V+D4`.GC9;````3K+@`#``V6`V2*IZH``\#E___^]N,0\*@`
M!,`P```@GN,`$```!.,P(`@`).,`(```)+D$`%+$*P``3/[`0```((_C0%`8
M`"3$*```3.GC(%`0`"18D/"T[)P`Q0%^[.D``P#8[`G__P#803`0"*<H``2G
M`0`!IW0`@H@```&Y%`!"[!(``0#8Z^0``P`-N10`8>-`,```!.-.4```).L6
M``,`#>-@,`@`!.-A4```)*<J``*G.P`0IP;_X^QI``,`V+D4`):Y%`!*ZZD`
M`P`-02I0`*=I``#E2"````#`,```#<[$*```3*_`Y?___!CL*`!4`'[$*```
M3*9!8/"\P.7___WMN00`-KD$`)+`(```'PW`Y0``#$/L*`!'`'S$*```3)'`
MY?__^\K`Y?___0?5!_#`L"BG=`!9N00`*>MO\/@`!`?^P.7___RYQ"L``$QZ
M["@`3@!\P.7___TPP#```$P!XR`P```$XT*P```$D@!)?J?T_SCC,#````3C
M,%`@`"2G*``%03`0$.PN_W9@=J?T_Y3$*```3%7`Y?___"ZG]/^IP%```$Q)
MXR!0```"IX0`!\#E```;D:?T_[&Y!``VP"```!Z)P.4```OGQ"L``$PT["C_
MI`!\I_3_[:=H``2G]/]NP.7___V8IRD``<#E___](T%`\`CC,/````2G"?_P
MN8``\*?[_U#7!_``\`#K[_"@`"1!</"@IVD``*=9``#`(```2[7C("````3`
MY?___H,```<'!P<'!\`0``!+\,`@``!+[>P2``J`9,08``!+?^P8``0`?`?Q
M!_X'!P<'!P?`$```2]S`(```2]FY"0`2ZP$``P`*ZS$`/P`,N0@`,.LS``$`
M"NPX``T`?,08``!+8NP8``<`?,`@``!+P`?Q!_X'!P<'!P?KO_!8`"3`L```
M2[7C\/]@_W&5`+``IW0`%<`0``!+5^,0$````J>$``C$*```2V/`Y?___(S`
MY?___ZV2`;``Z[_P^``$!_[`]/___[@'!^MO\#``)./P_-#_<;)/`+#KNP`@
M``VR3P"Q01#PJ-('\RBP**<)``1!4"`XXT!0```$XS!0"``$ZZ0`(``,XZ`0
M```DZV,`(``,XV`0$``DP$H`````XT`0"``DP#H`````XS`0&``D05!0$*<;
M`""G!__>XS#Q$``$XX#Q&``$XQ#Q(``$XY#PJ``$XP#PL``$04#PN*>I`$"Y
M!`!QX]!````$N00`[>/@0#``@KF"`..Y@@#I[!X@OR%5[!X@/@%6XQ!`<``D
MN00`.+D$`)"Y!`"'ITL`"*>G"MCCX"````3C8"`(``3C8/"@`"3C0"`0``3C
M`"`8``3LKB"_)56YYP"4[*X@.@56N8``EKF"`)#K5@`"``SC</"P``3L5@`A
M'E;">EJ">9GL-2"_`%6Y"`!PN><PU.,0\*@`!+F``-["&EJ">9FY@@#4XQ`@
M(``(N>APC;D(`!KKK@`"``RY"``9[*X`(1Y6[)$@OP!5N>>@9;F``&FY@@!C
M[-$[OR55XU#PP``$[-D`.@56PEI:@GF9N0@`V+D(`%/L?2"_`%7LC3N_)57K
M.0`"``SLAP`Z!5;L.0`A'E;C$/"X``3"&EJ">9FY"``4N0@`%NQJ(+\`5;F"
M`*.Y"``8N>1PBNR1(+\`5>S1.[\E5;D$`*WLJ0`Z!5:Y@@"&XQ#PR``$N0@`
MA<(:6H)YF;D(`(JYZ&!1ZZ<``@`,[&,@OP!5[*<`(1Y6['@@OP!5[(@[OR55
M[(<`.@56N8(`.N/0\-``!+F``#G"VEJ">9FY@@`VN0@`-;GH8%VY"``X[&H@
MOP!5ZXD``@`,[(D`(1Y6[),@OP!5N8(`J.PS.[\E5;GD<!KCT/#8``2Y@@`6
MPMI:@GF9N0@`%;D$`*.YZ&!=[*D`.@56[&@@OP!5N0@`&NLW``(`#.PW`"$>
M5KF"`(/L<2"_`%7LH3N_)56YY)`8N00`BNR'`#H%5KF"`!;CT/#@``2Y"``5
MPMI:@GF9N0@`&+GH8%WLH3N_)57L8R"_`%7KB0`"``SLB0`A'E;LD2"_`%7L
MJ0`Z!5:Y@@`XXQ#PZ``$N8``-\(:6H)YF;F"`#:Y"``UN>A@4;D(`#KL:""_
M`%7KIP`"``SLIP`A'E:Y@@"*[',@OP!5[-,[OR55N>20.+D$`(WLAP`Z!5:Y
M@@`VXQ#P\``$N0@`-<(:6H)YF;D(`#BYZ&!1ZXD``@`,[&H@OP!5[(D`(1Y6
MN8(`J.R3(+\`5>S3.[\E5;GD<#JY!`"M[*D`.@56N8(`-N,0\/@`!+D(`#7"
M&EJ">9FY"``ZN>A@4>NG``(`#.QH(+\`5>RG`"$>5KF"`(KL<R"_`%7LTSN_
M)56YY)`XN00`C>R'`#H%5KF"`#;C$/$```2Y"``UPAI:@GF9N0@`.+GH8%'K
MB0`"``SL:B"_`%7LB0`A'E:Y@@"H[),@OP!5[-,[OR55N>1P.KD$`*WLJ0`Z
M!5:Y@@`VXQ#Q"``$N0@`-<(:6H)YF;D(`#JYZ&!1ZZ<``@`,[&@@OP!5[*<`
M(1Y6N8(`BNQS(+\`5>S3.[\E5;GDD#BY!`"-[(<`.@56N8(`-N,0\1``!+D(
M`#7"&EJ">9FY"``XN>A@4>N)``(`#.QJ(+\`5>R)`"$>5KF"`*CLDR"_`%7L
MTSN_)56YY'`ZN00`K>RI`#H%5KF"`#;C$/$8``2Y"``UPAI:@GF9N0@`.KGH
M8%'KIP`"``SL:""_`%7LIP`A'E:Y@@"*[',@OP!5[-,[OR55N>20.+D$`(WL
MAP`Z!5:Y@@`VXQ#Q(``$N0@`-<(:6H)YF;D(`#BYZ&!1ZXD``@`,[&H@OP!5
M[(D`(1Y6N8(`J.R3(+\`5>S3.[\E5;GD<#JY!`"M[*D`.@56N8(`-N,0\2@`
M!+D(`#7"&EJ">9FY"``ZN>A@4>NG``(`#.QH(+\`5>RG`"$>5KF"`(KL<R"_
M`%7LTSN_)56YY)`XN00`C>R'`#H%5KF"`#;C$/$P``2Y"``UPAI:@GF9N0@`
M.+GH8%'KB0`"``SL:B"_`%7LB0`A'E:Y@@"H[),@OP!5[-,[OR55XQ#Q.``$
MN>1P.L(:6H)YF;F"`#:Y!`"MN0@`->RI`#H%5KGH8%&Y"``Z[&@@OP!5[-,[
MOR55ZZ<``@`,[-,@.@56[*<`(1Y6P#H`````N>>@>..`\4``!+F``'G"BEJ"
M>9FY@@!VN>A@&+D(`'7K60`"``RY"`!][%D`(1Y6[)<[OR55[)<@.@56[&H@
MOP!5N>=0VNN#``(`#+F``-.Y@@#6N0@`T;D(`-FY!`"8[),`(1Y6[#T[OR55
MN>>0%>P](#H%5KF"`!?CH/%(``3C@/%0``3"JF[9ZZ'"BF[9ZZ&Y"`"FN1H`
MA;D:`*'L9R*_/E6Y"`"C[&<"(1Y6[#H[OR55N>=@&>PZ(#H%5KF"`!WL?2*_
M/E6Y&@"!['T"(1Y6N0@`@^,P\5@`!,(Z;MGKH;GG<%:Y&@`YN>>@E>P8.[\E
M5;D:`#GL&"`Z!5;CD/%@``2Y"``QPIINV>NA[-,[OR55N1H`ENS3(#H%5NQJ
M(K\^5>QJ`B$>5N.@\6@`!+GG8%?"JF[9ZZ&Y@@!8N1H`I[D:`)7L>"*_/E6Y
M"`"=['@"(1Y6[(D[OR55[(D@.@56N>=PUK/!`&CC@/%P``3"BF[9ZZ&Y&@"&
ML\T`9KF"`-.Y&@"MN0@`INQ:.[\E5>Q:(#H%5NQC(K\^5>,0\7@`!.QC`B$>
M5L(:;MGKH;GG8#>Y&@`7N8(`.>QY(K\^5;D:`(/L>0(A'E:Y"`"%N>=P5NR8
M.[\E5;F"`%KLF"`Z!5:Y&@`5XS#Q@``$N0@`&<(Z;MGKH>R:(K\^5;D:`#;L
MF@(A'E;LT3N_)56YYY!7[-$@.@56N8(`6..@\8@`!+D:`#7"JF[9ZZ&Y"``]
MN1H`I^QX(K\^5>QX`B$>5NR#.[\E5>R#(#H%5KGG<-FSP0!XXX#QD``$PHIN
MV>NAN1H`B;/-`)>Y@@#1N1H`K;D(`*GL6CN_)57L6B`Z!5;L82*_/E7L80(A
M'E;C$/&8``2YYV#7PAINV>NAN8(`T[D:`!>Y&@"-[',BOSY5N0@`A>QS`B$>
M5NPX.[\E5;GG<%;L."`Z!5:Y@@!:XY#QH``$N1H`%<*:;MGKH;D(`!.Y&@"6
M[#HBOSY5[-$[OR55[#H"(1Y6[-$@.@56N><P5^.@\:@`!+F"`%C"JF[9ZZ&Y
M&@"5N1H`I[D(`)WL>"*_/E7L>`(A'E;LB3N_)57LB2`Z!5:YYW#3L\$`:..`
M\;``!,**;MGKH;D:`(.SS0`VN8(`T;D:`*VY"`"C[%H[OR55[%H@.@56[&$B
MOSY5[&$"(1Y6XQ#QN``$N>=@U\(:;MGKH;F"`-FY&@`7N1H`C>QY(K\^5;D(
M`(7L>0(A'E;LF#N_)56YYW!6[)@@.@56N8(`6N,P\<``!+D:`!7".F[9ZZ&Y
M"``9N1H`-NR:(K\^5>S1.[\E5>R:`B$>5NS1(#H%5KGGD%?CH/'(``2Y@@!8
MPJINV>NAN1H`-;D:`*>Y"``]['@BOSY5['@"(1Y6[(,[OR55[(,@.@56N>=P
MV;/!`'CC@/'0``3"BF[9ZZ&Y&@")L\T`E[F"`-'L82*_/E6Y&@"M[&$"(1Y6
MN>=@U[F"`-.Y"`"IN1H`C>Q:.[\E5>S3(K\^5>Q:(#H%5NS3`B$>5KGGT):Y
M@@":N0@`A>,0\=@`!.PX(+\`5>Q8.[\E5<(:;MGKH>Q3`#H%5KD:`!>Y&@`9
M[)HBOSY5N0@`%>R:`B$>5N.@\>``!+GGD'W"JF[9ZZ&Y@@"'N1H`INQA(+\`
M5>P1.[\E5>P6`#H%5KD:`*CC@/'H``2Y"`"APHJ/&[S<ZQ,``@`,N1H`C>P3
M`"$>5NS1(+\`5;GDT%FSP0`H[#H[OR55[(H@OP!5N>80J;F``*:Y@0"EL\T`
M4N-P\?``!,)ZCQN\W.PX`#H%5KD(`*6Y!`!7XW#Q^``$N1H`6<)ZCQN\W.N6
M``(`#.R6`"$>5KGDT&FY@0`9N>C0U[F``!BY@0`6N0@`%;D(`*.SP0!M[#H@
MOP!5[*H[OR55[*,`.@56N0@`H>L8``(`#.P8`"$>5NS1(+\`5;GDT%GL:B"_
M`%7LBCN_)56YYA"IN8``H[F!`*6SS0!6[(8`.@56XW#R```$N0@`I;D(`*C"
M>H\;O-SK@P`"``RY!`!7[(,`(1Y6N1H`6>PZ.[\E5>R:(+\`5;F!`!BYY-"H
MN8``%KF!`!JY"``5[#D`.@56XW#R"``$N0@`,<)ZCQN\W.L6``(`#+GHT-?L
M%@`A'E;L82"_`%6YY&!8L\$`/;GF$-BY@`#9N8$`U;/-`%/L<R"_`%7L,SN_
M)57L-P`Z!5:Y"`#5N0@`T^LY``(`#.PY`"$>5KGD8).Y@0`3XZ#R$``$N8``
M%\*JCQN\W+F!`!FY!`!:N1H`6.R-(+\`5;D(`!7LW3N_)57LV``Z!5:Y"`#1
M[)T@OP!5ZQ<``@`,[!<`(1Y6XW#R&``$PGJ/&[S<N>A@9^QQ(+\`5;GD<%.Y
MYA"CL\$`=KF``*BY@0"EL\T`5^S=.[\E5>-@\B``!+D(`*7LV0`Z!5;":H\;
MO-RY"`#:N00`5NRM(+\`5;D:`%/LW3N_)57K.``"``SLV@`Z!5;L.``A'E:Y
MYC"!N>1P$[F``(FY@0"!ZQD``@`,N0@`A>P9`"$>5KD(`(WLT2"_`%6YY-!3
MN>80D^-@\B@`!+F``)K":H\;O-RY@0"5N0@`9[/!`":SS0!2['@@OP!5XV#R
M,``$N0@`E<)JCQN\W.R(.[\E5;D$`%;LAP`Z!5:Y&@!3N>B`.>N:``(`#.R:
M`"$>5KGDT*FY@0`9N8``%[F!`!JY"``5[(,@OP!5[&,[OR55XS#R.``$[&@`
M.@56PCJ/&[S<N0@`8>L7``(`#.P7`"$>5NQQ(+\`5;GD<%FYZ-#3N>80.;/!
M`&VY@``XN8$`-;/-`%;CT/)```3"VH\;O-SLIB"_`%6Y"``U[&8[OR55N00`
M7>QJ`#H%5KD:`%GCT/)(``3KF``"``S"VH\;O-SLF``A'E:YY'")N8$`&;GH
M<'VY@``:N8$`&+D(`!6Y"``VL\$`-^QC(+\`5>PS.[\E5>PV`#H%5KGH,%'K
M&@`"``SL&@`A'E;LT2"_`%6YY-!YN>80J;F``*:Y@0"GL\T`<^PU(+\`5>R%
M.[\E5;D(`*?L@P`Z!5:Y"`"HXU#R4``$['H@OP!5[(H[OR55PEJ/&[S<XZ#R
M6``$N1H`6<*JCQN\W.N6``(`#.R6`"$>5KGDT&FY@0`9N>C0VKF``!.Y@0`6
MN0@`%>R'`#H%5K/!`'VY"`"!ZQ,``@`,[!,`(1Y6[-$@OP!5N>306;GF$*FY
M@`"GN8$`I;/-`%?L:""_`%7L.#N_)56Y"`"E[#8`.@56XX#R8``$PHJ/&[S<
MN00`6+D:`%GKEP`"``SLEP`A'E:YY-!YN8$`&;F``!:Y@0`7N0@`%;D(`*/C
M@/)H``3L.B"_`%7"BH\;O-SLJCN_)57LHP`Z!5:Y"`"AZQ8``@`,[!8`(1Y6
M[&$@OP!5N>1@6>QZ(+\`5;GHT-CLBCN_)56SP0`MN>80J;F``*.Y@0"EL\T`
M4NR'`#H%5N/0\G``!+D(`*7"VH\;O-RY"`"HN00`7;D:`%GLVB"_`%7KDP`"
M``SLDP`A'E;L.CN_)56YY&")N8$`&>P]`#H%5KF``!?CH/)X``2Y@0`8PJJ/
M&[S<N0@`%;GH8%JY"``Q[&,[OR55[&,@.@56ZQ<``@`,L\$`9NP7`"$>5N-@
M\H``!.R!(+\`5;GF$'FYY("IPFJ/&[S<N1H`:;/-`):Y@`!]N8$`>KD(`'6Y
MZ)"7[%D[OR55[%D@.@56L\$`%NM]``(`#.Q]`"$>5KD$`-6SS0!1N>2`I^-@
M\H@`!,)JRF+!UKGH@(;`.@````"Y@0`7L\$`.+F``!/K@P`"``RY@0`:[(,`
M(1Y6N0@`%;/-`&.Y"``=XZ#RD``$N>>`U\*JRF+!UKF"`-FY&@"G['DBOSY5
M['D"(1Y6XY#RF``$PIK*8L'6N1H`F+/!`%JSP0`)L\T`E;D:`&WL,3N_)57L
M,2`Z!5:Y"``V[%,[OR55[%,@.@56N>=PJ+F"`*&Y&@":N0@`E;/-`%#L82*_
M/E7L80(A'E:YYV#7N8(`T^P9.[\E5;D:`%WL&2`Z!5:Y"``5[*$[OR55[*$@
M.@56L\$`*K/-`-+C@/*@``3CH/*H``3"BLIBP=;"JLIBP=:Y&@"'N1H`INQS
M(K\^5>QS`B$>5KGG<#;L:2*_/E6Y@@`Y[&D"(1Y6N1H`@[GG8%>Y"`"-N8(`
M4>R8.[\E5;D:`*7LF"`Z!5:Y"`"I[-H[OR55[-H@.@56[)$BOSY5XS#RL``$
M[)$"(1Y6PCK*8L'6N>>05KD:`#>Y@@!8N1H`-;D(`#WLTSN_)57LTR`Z!5;C
M$/*X``2SP0`=PAK*8L'6X]#RP``$N1H`%L+:RF+!UNQH(K\^5;D:`-GL:`(A
M'E:YYV")L\T`D;F"`(KL>B*_/E6Y&@`8['H"(1Y6N0@`&;GG<(;L43N_)56Y
M@@"#[%$@.@56XZ#RR``$PJK*8L'6N1H`IKD$`&WLTR*_/E6Y&@!HN0@`9>S3
M`B$>5KGGT#>Y@@`Q[%8[OR55N1H`H^Q6(#H%5KD(`*7L.CN_)57L.B`Z!5;C
M@/+0``3"BLIBP=:Y&@"'['$BOSY5['$"(1Y6XQ#RV``$N>=P7<(:RF+!UKF"
M`%:Y&@`=N1H`A>S6(K\^5;D(`(/LU@(A'E;L.#N_)56YY]!G[#@@.@56N8(`
M:KD:`!:Y"``3[#HBOSY5[#H"(1Y6N><P;;F"`&CL43N_)57CD/+@``3L42`Z
M!5;"FLIBP=:Y&@"7N1H`ENQH(K\^5;D(`)7L:`(A'E;LB3N_)57LB2`Z!5:Y
MYV!SL\$`2..`\O``!,**RF+!UKD:`(.SS0`TN8(`<>.@\N@`!,*JRF+!UKD:
M`*VY&@"G['$BOSY5N0@`H^QQ`B$>5NQ:.[\E5;GG<-;L6B`Z!5:Y@@#9XQ#R
M^``$N1H`C<(:RF+!UKD(`(6Y&@`6[&DBOSY5[&D"(1Y6[)@[OR55N>=@5^R8
M(#H%5KF"`%JY&@`5N0@`&>S1.[\E5>S1(#H%5NR:(K\^5>,P\P``!.R:`B$>
M5L(ZRF+!UKGGD%:Y&@`WN8(`6+D:`#6Y"``][-,[OR55[-,@.@56XZ#S"``$
ML\$`7<*JRF+!UN/0\Q``!+D:`*;"VLIBP=;L:"*_/E6Y&@#9[&@"(1Y6N>=@
MB;/-`)6Y@@"!N1H`J.R!(K\^5>R!`B$>5KGG@':Y@@!SN0@`J;D:`-?L6CN_
M)57L<R*_/E7L6B`Z!5;L<P(A'E:Y!``WXS`@(``(P#H`````XS`@(``DXQ#S
M&``$PAK*8L'6N1H`%KGH4&VYYW#8[)8@OP!5N>>@/>Q6.[\E5;D:`!/L60`Z
M!5:Y"``5[-HBOSY5ZUD``@`,[-H"(1Y6[%D`(1Y6N>?0-[D(`%2YZ`!]P%H`
M````XU`@$``DN>=@`\!Z`````.-P(!@`).QA(+\`5>.@\R``!,*JRF+!UKD(
M`.JY&@#H[($[OR55N1H`X.R&`#H%5N,0\*``!+D(`.BY"``6P.H`````X^`@
M```DP!H`````XQ`@"``DU0?S*+`HIW0`"NMO\V``!`?^N00`#:?T]0?`Y?__
M\<0'!^MO\#``)./P_V#_<>PH`%P`?,08```_Q^-P$````J>$`%.Y!`""N00`
M8^,`(```E+D$`)*5`"``IX0`3NP(``P]?D&0D`'C`)```)25`)``IW3_]AN8
MXZ!P```"IX0`'[D4`)FY!`"WN00`2;D$`#BY!``JP.7___!&["8`"0!^02F@
M`)4](`"GA``/0;"P"..@L````J=T_^FY!``JZV_PT``$!_Y!J:`!N>EP.[D$
M`"KK0P`#``I00&``ZV_PT``$!_ZGJ0``N00`*NMO\-``!`?^IY@``*?T_[\'
M!P<'ZZ_P4``DX_#^R/]QLD\`L+D$`*+KNP`@``U!,/"@LD\`L=('\3"P*,#E
M___Q;.PF`"$`?A@2ISA``%@@\+C`*P``\`#L(P`(@':E#Z``["``$V!VN00`
M*J<Y``+`Y?__\=(0$J<:__^($``?I_0`!*<8``#5!_$PL"BY%``AIW0`!NNO
M\8@`!`?^P.7___$+ZV_P,``DX_#^P/]QLD\`D.N9`"``#;)/`)'2!_$XD"CL
M*``)`'RY!`!BE0`@`*=T``O5!_$XD"BG=`"6ZV_Q<``$!_[`Y?__\=:Y!`"R
M["C_\@!\N00`*\#E___P/.PH`&8`?$&@(!.5+B`3IW0`!I4`H`&GA/_PE2X@
M$Z>$`&.G"```N00`%KD$`"JG.0``LEX`,J<4__ZY"0`ZIXD``+)>`(&G%/_^
MN0D`AAJ#IXH``KD4`(BY!``HP.7__^[;XZ#PH``DISD``KD$`**Y!`!(P%``
M`!%1P.7___%<N00`*D$P\*C`Y?__[Y7L*``-_WY8`/#`ITA``,`+``#P`.P$
M`"N`=KD$`"K`Y?__\,.Y!``JP.7___#^N00`*\#E___OV>PF_Z``?+D$`"O`
MY?__[H&Y!``FP.7__^[,I_3_>I4NH`&G=/^=E0"@`J>$_X.G]/^7N00`*L#E
M____4Z?T_]C`Y?__\%8'!P<'!P?K;_`P`"3`$```/G'C\/]8_W'CL!````3`
M4```,3#$2```/FG`,```$/.R3P"@ZZH`(``-LD\`H>,KH```!,!@```23L#E
M___P_KD$`%;E2/"@``#`0```#.;C*Z````3`,```$./`Y?__[UWK;_#8``0'
M_@<'!P?K?_`X`"3C\/``_W'C`/_X`"#C\/]8_W'C`/"@`"#C$/"@`7&Y!`"#
M09#PH+)/`+"Y!`"BZ[L`(``-N00`.;)/`+'2!Q``L"BG20__P"```!"\P.7_
M_^[+["P`$@!^[`+__P#8&!*Y%``@03+PH)4`,`"G=``B[`8`'P!^P%```#WZ
MX^!0```$N00`2+D$`#KC+K````3`Y?__[FGC0/"@`7'5!T``L"BG=``IZW_P
MX`$$!_X8$+D4`'&Y!``IN00`1Z<Y`"_`Y?__[J'L*/_8`'RY!`!)P(```#W-
MN00`5^.0@```!+D$`#KC*;````3`Y?__[SRG]/_3P.7__^^7ZV_P,``DX_#_
M0/]QLD\`8.MF`"``#;)/`&&Y!`"RT@?PN&`HN00`HY4],`"G=``$0:`P`:<(
M``"Y!``:IXD``+D$`"NR7@"!IQ3__D$P\+2Y"0"*P.7___VJ["@`EP!\IP@`
M`*?9``"Y!``2LEX`T:<4__ZY"0#2[(T`=L!EXW#PM``4Q-@``#UBZW<``P`-
MXR"P``"4N00`2Y4`L`"G=``-I_0`\$%`0`'C($```)25`$``IX0`!>PF__<]
M?KD)`$NY%`"402B0`KD$`(?C@-````C`Y?__[5KC((```"3L*``Y`'SC,-``
M``3C`+```)#C5S````1"`%``0>"P`1AP[`8`$`!\I_0`/.,0X```D$(0L`%!
MX.`!&''L&``R`'Q"</"@N00`M94]\*!!4%`!IW3_[9(]L`"GV0``XTV@``"0
M0DVP`:?;``'L1O_Y`'S5!_"X8"BG=`"@ZV_P\``$!_ZGF0``XXF@``"00HD@
M`*>;``'LAO_Y`'RG]/_KN00`M:?T_]G$V```/.#C<-````3C$'````*GA`!X
MN00`1Z>8```8*:>:``%!0$`(XS!````"IW3_^*<J``.Y%``"ZS```P`-XS#P
MJ``DP%```#TUXQ!0```2IW0`/,#@```]+>,@\*@`!.5,X````<#E___LS.,@
M\*``).PH_ZL`?+D$`#?C4/"H``2Y%`!YZW<``P`-N00`1\#E___O9^,@\*``
M!.,@T```)%"0\+3C4/"@``2GF@`!N10`F>LY``,`#4'C4`#E2.````"G]/\A
MXS#PJ``$N00`)\#E___MAN,@\*``).,@T```).PH_W(`?+D4``GK<``#``VG
M]/_7IYD``*?T_R#E2/"H`!"GF```I_3_G<#E___N2`<'LD\`(,`0```\9NLR
M`"``#>-`$```!+)/`#'`4```+R/C)#````3$2```/%G`,```#N/`]/__[OOK
M;_`P`"3C\/``_W'C`/_X`"#C\/``_W'C`/_X`"#C\/](_W'C`/"P`"#C$/"P
M`G&R3P"0ZYD`(``-LD\`D>.P\*\!<=('$`"0*,#E___MP\`````.W.,`\*``
M)+D$`&*G21`!ISD``KD$`"O`4```#LA!@/"NP.7__^ZMN00`*[D$`#BG21``
MP.7__^S$["0`,0!^['(``0#8N00`8KD4`'>Y!``GP.7__^P%N00`HNPH`!(`
M?+D4`+:Y!`!7N00`.+D$`$O`Y?__['5!*Z``D@`@`.,P\+`"<=4',`"0**=T
M``RY!``JZV_PZ`($!_ZGJ0``I_3_\,#E___MK`<'P/3___^`!P?K;_`P`"3C
M\/``_W'C`/_X`"#C\/ZP_W'C`/%(`"#C$/%(`7&Y!`"RN00`D[)/`'!!,/"T
MZW<`(``-P"````YFLD\`<=('$`!P*,#E___[OZ<Y`"^Y!`"BN00`*\#E___M
MANPH`!D`?,`@```.5+D$`#O`Y?___=>Y!``KXX#Q2`%QU0>``'`HIW0`[>MO
M\8`!!`?^N00`*<#E___LB,`P```.0,#E___KTKD$`&+L*/_=`'Q!D/%(08#P
MN)4`8`"GA`"D[*@`#P!\IP@``+D$`#:Y!``JLET`,J<4__ZGA`"$IP@``*=)
M``"Y!`!6LEX`1:<4__ZYZ6`DXQ!/__]Q[&$`-Z!EN>E@`:<!``&GA``.E2\0
M`*=T`""2`!``XQ`?__]Q[&$`&8!DZ^```0`,E2\0`*=T`!&2`!``ZR\?__]5
MIW0`"NL`'___4N,0'_[_<:?G_^^G"```IRD``+D$`#:R7@`CIQ3__KD)`":G
M"```ITD``+D$`%NGZ0__LEX`1:<4__ZY"0!+000@`>P._VT@9<`0```-QN.P
M\*@`).,0\*``)*<Y``*Y!``IP%````XPITD0`,#E___MB+D$`#BY!``IP.7_
M_^O!["8`#0!^6&#PT*4_@`#`:P``\`#L8P`H@';`,```#9RG*0``P.7__^LL
MN00`8NPH_S<`?)4`8`"G=/]@[*@`!P!\E2Z@`*>$``FG*0`!P&````UUI_3_
MIY4`H`&GA/_?I_3_];D$`"FG.0`!P.7__^TX[";_U`!^N00`.<`@```-9,#E
M___\Z;D$`"G`Y?__ZZBG]/\/P.7__^QSZ[_P6``DISD`+^/P_V#_<;D$`++`
MY?__[0;L*``%`'Q!L"`!N00`*^N_\/@`!,#T___KB0<'!P?KG_!(`"3C\/``
M_W'C`/_X`"#C\/]8_W'C`/"@`""R3P"@XQ#PH`%QZZH`(``-LD\`H=('$`"@
M*.PH`&0`?)4`(`"GA`!?IP@``*>9``"Y!``RLEX`DZ<4__ZG"1``N0D`DNQ)
M``$`V>Q``&\@9;D$`#)!L/"@N00`*\#E___M-^-9O___<>Q;`!_`9;GIL"6G
M40`!IW0`1^M"``$`#)4O4`"G=``1D@!0`.LO7___5:=T``KK`%___U+C4%_^
M_W&G1__ON00`*Z<Y`"_`Y?__[([L*``7`'SL*P`S(&6Y!``KP.7__^L3X^#P
MH`%QU0?@`*`HIW0`+>N?\/`!!`?^XQ#PH`%QU0<0`*`HIW0`(<`@```,JNN?
M\/`!!,#T___J]I4O4`"G=/_/D@!0`.-07___<>Q;_[)@9*?T_\62`"``I_3_
MSJ<I``"G]/_/P.7__^NM!P<'!^NO\%``)./P_U#_<;)/`*#KJ@`@``VR3P"A
M0;#PI-('\*B@*+D$`#O`(```#('`Y?__^='L*``N`'SC0/"D`!3$*```.9CK
M%``#``WC$"````CC4!`(``3C4!```"3L6/_C`'SC`!`0``3C`!`(`"1!$!`(
M[`;_^`!\N00`.\`@```,5L#E___YINPF_]@`?+D$`#O`(```#%#`Y?__^9OL
M*``N`'SC$/"D`!3$6```.6+KX0`#``WCX%````CC`.`(``3C`.```"3L"/_C
M`'SC,.`0``3C,.`(`"1!X.`([#;_^`!\N00`.\`@```,)<#E___Y<.PF_]@`
M?+D$`#O`(```#![`Y?__^67L*``N`'SC4/"D`!3$Z```.2SK10`#``WC0.``
M``CC,$`(``3C,$```"3L./_C`'SC($`0``3C($`(`"1!0$`([";_^`!\N00`
M.\`@```+\\#E___Y.NPF_]@`?+D$`#O`(```"^W`Y?__^2_L*``N`'SC,/"D
M`!3$*```./;K$P`#``WC$"````CC0!`(``3C0!```"3L2/_C`'SC`!`0``3C
M`!`(`"1!$!`([`;_^`!\N00`.\`@```+PL#E___Y!.PF_]@`?+D$`#O`(```
M"[O`Y?__^/GL*``N`'SC$/"D`!3$2```.,#K40`#``WC4$````CC`%`(``3C
M`%```"3L"/_C`'SCX%`0``3CX%`(`"1!4%`([.;_^`!\N00`.\`@```+D,#E
M___XSNPF_]@`?+D$`#O`(```"XW`Y?__^,/L*``N`'SC0/"D`!3$6```.(KK
M-``#``WC,%````CCX#`(``3CX#```"3LZ/_C`'SC(#`0``3C(#`(`"1!,#`(
M[";_^`!\N00`.\`@```+8L#E___XF.PF_]@`?+D$`#O`(```"R_`Y?__^(WL
M*``N`'SCX/"D`!3$*```.%3K'@`#``WC$"````CC,!`(``3C,!```"3L./_C
M`'SC`!`0``3C`!`(`"1!$!`([`;_^`!\N00`.\`@```+!,#E___X8NPF_]@`
M?+D$`#O`(```"R?`Y?__^%?L*``N`'SC$/"D`!3$.```.![K00`#``WC0#``
M``CC`$`(``3C`$```"3L"/_C`'SC4$`0``3C4$`(`"1!0$`([%;_^`!\N00`
M.\`@```*_,#E___X+.PF_]@`?+D$`#O`(```"O;`Y?__^"'L*``N`'SC,/"D
M`!3$2```-^CKXP`#``WCX$````CC4.`(``3C4.```"3L6/_C`'SC(.`0``3C
M(.`(`"1!X.`([";_^`!\N00`.\`@```*R\#E___W]NPF_]@`?+D$`#O`(```
M"L7`Y?__]^OL*``N`'SC4/"D`!3$Z```-[+K%0`#``WC$.````CC(!`(``3C
M(!```"3L*/_C`'SC`!`0``3C`!`(`"1!$!`([`;_^`!\N00`.\`@```*FL#E
M___WP.PF_]@`?+D$`#O`(```"ES`Y?__][7L*``N`'SC$/"D`!3$*```-WSK
M,0`#``WC,"````CC`#`(``3C`#```"3L"/_C`'SC0#`0``3C0#`(`"1!,#`(
M[$;_^`!\N00`.\`@```*,<#E___WBNPF_]@`?+D$`#O`(```"E[`Y?__]W^Y
M!``R["@`"0!\P"````I)P.7___F@N00`.\`@```*5,#E___W;+D$`#+L*``)
M`'S`(```"E+`Y?__^8VY!``[P"````I0P.7___=9N00`,NPH`!H`?,`@```)
M\,#E___Y>M4'\*B@**=T`"/`,```"DO`(```"@+KK_$```3`]/__^6FY!``[
MP"````HTP.7___<UN00`,NPH_^4`?,`@```)^L#E___Y5J?T_]S`Y?__Z.4'
M!P<'Z[_P6``DP"````GJX_#_4/]QLD\`L$$P\*3KNP`@``VR3P"QT@?PJ+`H
MP.7___<+["@`'`!\OR$@`*>$`!?`)P```#"YA``"N0,`$.PQ/[\!5=4'\*BP
M*+D4`".G=``*Z[_Q"``$!_ZG.```I_3_\\#E___HJ`<'8`#P@&`@\(A@0/"0
M8&#PF.L_\!@`),08```VT>/P_SC_<;D$`$)!`/%HLD\`($%0\,CK,@`@``VR
M3P`QXR`0```$T@?PP#`HXU#PN``DXP#PL``DY4CPH``!Y4CPJ```05#PH*<Y
M``+`Y?__Z$"G*0#_P.7__^?[ZX_P0``DX^#P`/!QX_#P`/]QXP#_^``@N2$`
M_J<D__BY!`#^X_#_4/]QXP#PJ``@XQ#PJ!!QN00`@K)/`*"G20`"ZZH`(``-
MISD``+)/`*'2!Q``H"C`Y?__YHWLDO__`-GL"3"``%7LE`"Z`'RY"0"00;#P
MH.R4`)\`?+D$`#FY!``HITD``,#E___F=.PH`+C_?+D$`#NY!``HP$$``0`(
MP.7__^AW["@`I?]^N10`,NP\`'@'?>,3O_C_<>P;`')`9>Q!/K\`5<!0```V
M2]4'4``0`*>$`'WC$!___W'L&P!A0&7L2``M`'SL2``<`7SL2``.`GS`X```
M-C35!^``$`"GA`!FXQ`?__]QP"```#8IU0<@`!``IX0`6^,0'___<<`P```V
M'M4',``0`*>$`%#C$!___W'L&P`T0&7`0```-A#5!T``$`"GA`!"XU`?__]Q
MP.```#8%N00`%=4'X`!0`*>$`#7C$%___W'`(```-?C5!R``$`"GA``JQ`@`
M`#7PXQ!?_O]QXP!?_O\@IX0`'^,07_W_<>P;_]*@9<*4``$``,`Q__\``.R3
M_V=@9*<I___C@/"H$''5!X``H"BG=``CZX_P\!`$!_ZYZ;`AN0@`*:?T__"G
M"___P"'__P``N8$``J<+``&G]/]`P"````B\P.7___[(P"````BOP.7___["
MP.7__^=CZ^_P<``DX_#_8/]QP.7__^4ZP.7__^47["@`!@!\XR`@```$Z^_Q
M$``$!_X'!P<'ZV_P,``DX_#_0/]QLD\`H+D$`&+KJ@`@``U!,/"TLD\`H<`@
M```(BM('\+B@*,#E___U<>PH`!H`?+D$`+*5`"``IX0`$[D$`#;`Y?__Y4/L
M*``<`'S5!_"XH"BG=`!6ZV_P\``$!_[5!_"XH"BG=`!-N00`-L`@```(8.MO
M\/``!,#T___W<Z<(``"Y!``[N00`%J=)``"R7@`AIQ3__K)>`$.G%/_^N0D`
M)KD)`$M!DD`"N00`*<#E___E'..P\*@`),`````'T>,`\*``)+D$`$FY!`"R
MP%````@_ISD``L#E___GE]4'\+B@**=T``VY!``[P"````@@ZV_P\``$P/3_
M__<SP.7__^;$!P?K;_`P`"2R3P`0X_#^*/]QZS$`(``-LD\`,>,P\,@`)-('
M\=`P*,!````T]4&`\-2Y!``XTD?P^$`0T@_PX$!8T@?P\$!HXR#PP``DP"``
M``=YP.7___37["@`"0!\N00`LI4`(`"G=`*6P.7__^1KP.7__^1(["@!.0!\
MXZ`@```"IX0!,Z<(``"G*0``N00`6K)>`"6G%/_^N0D`*NNR``$`#:>[``&Y
M!``KP.7__^2:XP"@``"4N00`DI4`H`"GA`)\N00`>[D$`-*Y!`!+N00`*;F$
M`&#`4```![.G.0`"0:"@`<#E___G#;DA`'NY!`!+N>*@1^,`H```E+GIL%2G
M6P`"N2$`5+GB4%2YZ4`K09"0`N.R7_[_<94`H`"G=/_606#Q&,`@```'6J?T
M``FG:P`(XR!O^/\"IX0`(+D$`#C`Y?__]%ZY!`!R["C_\@!\E0`@`*>$_^W`
MY?__],+L*/_H`'ZY!``GP.7__^4ZN00`8NPF`!T`?$&0\/CC8)````*GA``5
ME0!@`*>$`*FY!``FP.7___2E["8`E`!^IYL`".-@D````J=T_^^G"```N00`
M[:<9``"R7@`>IQ3__KD)`!VGN0``N00`IK)>`+JG%/_^N0D`MAJQI[H$!+D4
M`)NY!``IP.7__^/[P`````:TX]#PL``DXP#PH``DN00`<J<Y``*Y!`!)P-``
M``<@X]#PJ``DP%````<5P.7__^9PN00`)Z<Y`<#`Y?__Y5GL)@`+_W[`Y?__
MY2-8,"``[#8!BA%^0=#Q0+D$`">Y!``]P.7__^7%&*+L)@`-`'Y80/%8IUA`
M`,!+``#P`.Q%`(2`=KD$`&?$B```,[KC</#```3`0```!P3C4'````3C((``
M``2G.0`"P.7__^61I[D``.-@\,@`!-4'\=!@**=T`ARY!``KZV_R"``$!_ZY
M!``FIYL`",#E___DBKD$`&+L*/]5`'RG]/]JIVD``*?T_V9!8/#@XR!@```"
MIX0`%;D$`#C`Y?__\X/L*``'`'R5`"``IW0`':=K``CC(&````*G=/_OIRD`
M#:=Y``VGN0`-P.7__^-<P*````:$N00`DKD$`-*G"`!3I_3^QL#E___D3KD$
M`*+L*/_@`'RG"```I^D``+D$`#*R7@#CIQ3__KD)`.+KO@`!``VGNP`!I_3^
MF5A@\5S`Y?__XN'L8O]Z8'98L/%8IR@!P,"[```!_^RR_W!@=KD$`"G`Y?__
MXQ^Y!``XN00`LL`@```&FL#E___S);D$`#+L*`$``'SC$/#```3C(!````3`
MY?__]S.Y!`!B["@`\@!\IP@``*=)``"Y!``VLEX`0Z<4__ZY"0!&[$P`'@-^
MN10`5,`0```&<^,E;_S_<;)=`!*G%/_^IW0`#^Q(`4,$?J=*__NY%`#D04Y@
M`)4O0`"GA`$XN00`.,`@```%L,#E___RX.PH`,4`?.,`(```E.P(`+\`?NP(
M`+PP?L`P```%UL`@```%F[D$`&?`Y?__]/7`Y?__Y$;`4```!J#`$```!6RY
M!`#2XU#PL``DN00`2;D$`"OC$/"@`"3CT/"H`"3`4```!C>G.0`"P.7__^4I
MI_0`-,#E___CY%@@(`"G+@`1IW0`-<#E___D&\`P```%1+D$``*GJ@`!P(``
M``9NXS#PH``DN10`VKD$`&>Y!`!)N00`*^.`\+@`).,`\*@`),!0```&#>/0
M\+``)*<Y``+`Y?__Y/6Y!``KISD!P,#E___CWNPH_\?_?KD$`"?`Y?__Y*:Y
M!``[P"````4`P.7___2*N00`*\#E___\T:?T_JJY%`!#XQ#PP``$N00`9^-0
M$```!,0H```R0N-`\*``)*<Y``+`0```!6SC("````3`Y?__Y!RG]/Z+P.7_
M__ROXW#PR``$U0?QT'`HIW0`I+D$`"OK;_((``3`]/__XQ>Y!`#2I_3]M./@
M\,``!.-@X```!*?T_PNY!``FISD``,#E___D9+D$`&+L*/\^`'[`Y?__^V2Y
M!`""["3_-@!\ITD``.,PC_;_<;D$`";`Y?__X@VY!``F03#PVJ=)``;`Y?__
MY!3L)@!J!GS`,```))_5!3``\-JG=/\7XS"/SO]QITD``+D$`";`Y?__X>^Y
M!``FN00`/:=)`"C`Y?__X_;L)@!,*'S`X```!:W`4```!'FY!`!)XU#PH``D
MN00`9[D$`"N2`/%HX^#PL``DX]#PJ``DP%````4ZISD``L#E___D-*?T_TGC
M,/#```3C4#`(``*GA/[$IP@``*<9``"Y!``ELEX`$J<4__ZY"0`5[!S^M@-]
MX^%?_/]QP$````4-LET`3J<4__ZYXH!EI_3^I\#E___C2L`@```%`L#E___Z
MH`<'ZW_P.``DX_#_4/]QP*```#%>LD\`L.,0H```!.N[`"``#;)/`+'CD;``
M``1!@/"DT@?PJ+`HT@"0L9"PN00`.,`@```$'\#E___Q7>PH``<`?)4Q(`"G
MA`#2P.7___=KXR"@```$XY*P```$N00`*:=9``.G20`!P#````3=P.7__^&1
MN00`DNPH`!\`?.,P(!``!.-PH```!.,P,```!,!````$RN,GL```!,#E___A
MBN-`D!``!.,P0```!)%`,`VG=`"SXW"@```$IUD``^,GL```!*=)``'`,```
M!+#`Y?__X6"Y!`"2["@`'`!\N00`.,`@```#JL#E___Q`[D$`$+L*`"!`'SC
M$)`0``3C)[````3C,!````3`Y?__X5+CH*````2G20`!XWJP```$P#````2%
MN00`)\#E___@DL!````$B+D$`#*Y!``GP.7__^$XN00`.,`@```#<N.*L```
M!)(`@+'`Y?__\,O$*P``,1BY!`"2["@`+`!\N00`*:<Y`<#`Y?__XBSL`@`!
M`-CL#``6`7_L*``3$7ZY!`!2Q+@``##ZN00`2<`@```$9N,PL```!,#E___B
ML]4'\*BP**=T`#GK?_#H``0'_L0H```PX\#E___[E,0K```PX;D$`)+L)O_,
M`'S`(```!#7`Y?__XI:5`"`!IX3_-Z?T_RSC4)`0``3$Z```,,;C(%````3C
M,.````3`Y?__\AVG]/]_XR>P```$P.7__^(9I_3_2<#E___B)`<'ZY_P2``D
MX_#_4/]QLD\`H+D$`)+KJ@`@``VR3P"AT@?PJ*`HP.7___6ZISD`+[D$`++`
MY?__XJ?L*``%`'Q!L"`!N00`*\#E___A+4$P\*2Y!`"RP"````,#P.7___`S
M["@`$P!\XQ`@``"4[!@`#0!^[!@`"C!^[)@`!P!\E0"0`*=T``O5!_"HH"BG
M=``@ZY_P^``$!_ZY!``KITD`!,`P```#-\#E___@C>PF_^T`?M4'\*B@**=T
M``JY!``IZY_P^``$P/3___"UP.7__^&Z!P<'!P<'Z^_P<``DIRD`@./P_V#_
M<<#E___?W,`Q9T4C`<`/[\VKB>,P(```).,`(`@`),!/F+K<_L!1$#)4=N-`
M(!``).-0(!@`),`_P]+A\.5(("@``.,P("``).5((#```.5,('@``.OO\1``
M!`?^!P<'!^MO\#``).L4``,`#;D$`++C("`H``2Y"``2[%$@OP!5N00`E./P
M_V#_<>-`L#``!+D$`*.Y,0`AI\0`!*=+``'C4+`H`"3K"0`=``RY"``$XP"P
M,``DX]"P>``2IW0`A4%PL#CLG`"J/W[L:?_``-B(8``&[.8``0#8[!X?N095
M[%'_P`#90=&@`.N%``8`#*>+``'L2#Z_`%6GA``I[$@`&@%\[$@`#0)\TC]P
M`*``N00`*T&@H$#`Y?__Y!32/W``H`"Y!``K0:"@0,#E___D"M(_<`"@`+D$
M`"M!H*!`P.7__^0`[*T`*H!DZX@``@`,TC]P`*``N00`*\#E___C\M(_<`"@
M0+D$`"O`Y?__X^K2/W``H("Y!``KP.7__^/BTC]P`*#`N00`*T&@H0#`Y?__
MX]BGA__>IYK_P(E@``8;EKD4`)FY!``]N00`)[D$`$G`Y?__X?)0D+!XZV_P
MT``$!_ZGB`!`&XT9B4%PL#BY\C")N00`)[D8`"VY!``ZN10`:+D$`$;`Y?__
MX=<8.%HPL'A0,+!X[#;_XD!^&YBY!``KN0@`IKD4`)G`Y?__XYFG]/]8N00`
MVJ?T_\;K?_`X`"2Y!`"SXX`P*``$XY`P,``$[!@ZOSU5N10`,4%#L#B2@$``
MIQH``;D$`**Y%``!02"P../P_V#_<;D(`"#L'`">.'ZGZ`!`N?D0/NSA`%^`
M=NP3__\`V+D$`#+K00`(`-[L2`!/`'[L=/__`-@85.P$/K\`5:>$`";L"``9
M`7[L"``,`G[C("0``#881T$P(0#7_R``(`#C(#0``#:G2O__U_\P`#``03`Q
M`.,@-```-M?_,``P`$$P,0#L2``B`7[K)0`"`-[C(#0``#;7_S``,`#C(#4`
M`#;7_S$`,0#C(#8``#;7_S(`,@#C(#<``#;7_S,`,P!!,#0`IR;_YKD6`.'&
MX````*"Y!``KP.7__^,'US>P.+`XISD``.PY``=@5>PY"`]@5>PY$!=@5>PY
M&!\@5;D$`"OL@P`?`%7C@+!P`"3`Y?__XNO2`Z``L`2Y!``KT@.@!+`,T@.@
M"+`4T@.@#+`<T@.@$+`DZW_PV``$P/3__^!@IU@`.+GY$'7L4?_,@';L%___
M`-BY!``RZW$`"`#>['@`3P!^[.?__P#8&%?L!SZ_`%6GA``F[`@`&0%^[`@`
M#`)^XR`D```V&'Y!,"$`U_\@`"``XR`T```VIWK__]?_,``P`$$P,0#C(#0`
M`#;7_S``,`!!,#$`['@`(@%^ZT4``@#>XR`T```VU_\P`#``XR`U```VU_\Q
M`#$`XR`V```VU_\R`#(`XR`W```VU_\S`#,`03`T`*=&_^:Y%@`AQB`````(
MI_3_;=<`,``P`-<`,``P``<'!P?$6```+;3`]/__W:T'!P<'ZV_P,``DN00`
M'Z?[_V#C$/```"3`P```+(8'!^-`\1``!.MO\-``!`?T!P<```````(``25S
M+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!
M4CHZ0D]/5```+W!R;V,O<V5L9B]E>&4``"]P<F]C+R5I+R5S`&5X90`N`%!!
M4E]414U0``!005)?4%)/1TY!344``#H`+P!015),-4Q)0@``4$523$Q)0@!0
M15),-4]05```4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`
M4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)5
M1P``4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@``4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X``#$`;'-E96L@9F%I;&5D``!R96%D(&9A
M:6QE9`!,1%],24)205)97U!!5$@`4UE35$5-```E,#)X```E<R5S)7,E<P``
M<&%R+0``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U
M<B!O<&5R871I;VXI"@``4$%42```<&%R;```+G!A<@``<VAO<G0@<F5A9```
M)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E
M<P``&`!P97)L```P`%!!4CHZ4&%C:V5R.CI615)324].```Q+C`U.0!5;F%B
M;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@``+64``"TM``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O
M9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-
M04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@
M(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!
M1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY
M("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D
M8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M
M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I
M<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I
M('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?
M<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E
M>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I
M.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D
M<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D[
M"D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P
M96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R
M7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B
M72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I
M<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF
M("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP
M(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)
M4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8
M(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T
M;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@
M6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA
M("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E
M>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T
M;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA
M;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;
M4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P
M.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ
M0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L
M('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7
M:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_
M.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*
M7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N
M86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%
M35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T
M87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]7
M05).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D
M<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R
M;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E
M<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD
M7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H
M<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!0
M05(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!
M0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*
M:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2![
M"F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]
M"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&
M2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A
M8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,
M17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%
M7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C
M=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@
M)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE
M(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,
M12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@
M<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N
M86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D[
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_
M.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#
M86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L
M"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M
M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U
M8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D
M;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD
M;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E
M7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF
M;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F
M24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F
M:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M
M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E
M96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`]
M(%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD
M:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W
M)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B
M.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL
M92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP
M72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@
M+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E
M<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S
M("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+
M6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@
M<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]
M"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@
M(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N
M9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%0
M4%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y
M('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM
M<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*
M<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL
M7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6
M(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%
M3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N
M;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`
M05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI
M+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE
M;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@
M)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@
M>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I
M970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^
M/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A
M73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD[
M"FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\
M.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P
M87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;
M17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A
M7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N
M=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,[
M"B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@
M*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P
M:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL
M92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I
M92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q
M("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)5
M3D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O
M=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@
M)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@
M>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*
M?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]
M"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z
M(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]
M"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@
M;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E
M(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P
M('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(*
M*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\
M9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]
M*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S
M("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1]
M.R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E
M;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D
M9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y
M+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@
M*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E
M<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[
M)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II
M9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q
M(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA
M;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D
M9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS
M<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@
M)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F
M*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*
M;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@
M/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD[
M"E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT
M96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K
M*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@
M07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL
M"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D
M(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II
M<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@
M;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R
M:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?
M;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D
M9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#([
M"B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE
M(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD
M8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG
M=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#
M04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO
M861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!
M1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I
M;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]
M"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N
M86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@
M24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D
M:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T
M0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A
M9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L
M("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S
M*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C
M:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M
M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^
M9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_
M<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK
M*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@
M/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C
M=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R
M+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE
M;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?
M;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R
M7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C
M=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T
M;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D
M7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z
M("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R
M8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL
M95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]
M("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N
M86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N
M86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E
M*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ
M4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T
M:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q
M=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R
M.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V
M87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X
M<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#
M;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!]
M.PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L
M87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U
M<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E
M('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C
M86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R
M7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX[
M"GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?
M5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%
M35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD
M("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U
M:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@
M)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S
M97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@
M)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N
M86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-
M)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?
M9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F
M:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S
M971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D
M("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E
M=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE
M+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]
M?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO
M<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E
M;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D
M<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP
M(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT
M<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA
M;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B
M)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T
M96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D
M9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T[
M"F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N
M86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE
M*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G
M;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI
M;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@
M)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF
M("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S
M>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@
M+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E
M>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-
M4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M
M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X
M97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?
M9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O
M9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@
M0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7
M:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA
M;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?
M9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U
M8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK
M*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)
M6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'
M($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*
M?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[
M(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D
M14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2![
M"F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R
M;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN
M(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*
M<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@
M)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X
M<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R
M;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF
M="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G
M<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P
M<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S
M("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I
M9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`[
M"GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I
M9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`%5315(``%53
M15).04U%``!414U01$E2`%1-4``O=&UP`````'!E<FQX<VDN8P``0T%#2$4`
M``````````$;`SL```#L````'/__@'````9$__^"\````0C__X/X```!./__
MFI````%X__^;<````=C__YP````""/__G7````)$__^=Z````H#__Y[H```"
MP/__H8@```,`__^AP````Q3__Z+````#6/__HL@```-L__^E,````ZS__Z5H
M```#V/__IL````0@__^L4```!%3__ZS(```$A/__K4````2P__^O4```!/3_
M_Z^````%%/__L)````5T__^WD```!<3__[G0```&`/__NJ@```:$__^[&```
M!JC__[S8```&Z/__OS````<H`````````!0``````7I2``%X#@$;#`^@`0<.
M`````!0````<__^!X````$(``````````````!0``````7I2``%X#@$;#`^@
M`0```````#P````<__^"N```%I8`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[0
M!P,6>@K/SLW,R\K)R,?&#J`!0@L```````!<````7/__F1````#<`$:&#H<-
MB`R)"XH*BPF,"(T'C@:/!48.P`("F`K/SLW,R\K)R,?&#J`!0@M<"L_.S<S+
MRLG(Q\8.H`%""TX*S\[-S,O*R<C'Q@Z@`4(+```````L````O/__F9````"0
M`$:*"HL)C`B-!XX&CP5&#M@#`GP*S\[-S,O*#J`!0@L````X````[/__F?``
M``%J`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.X`-V"L_.S<S+RLG(Q\8.H`%"
M"P`````X```!*/__FR0```!T`$R&#H<-B`R)"XH*BPF,"(T'C@:/!48.R`("
M8,_.S<S+RLG(Q\8.H`$````````\```!9/__FV````$``$:'#8@,B0N*"HL)
MC`B-!XX&CP5&#J`A3`[((@*:"L_.S<S+RLG(QPZ@`4(+````````/````:3_
M_YP@```"G@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#N`"`P%6"L_.S<S+RLG(
MQ\8.H`%""P```````!````'D__^>@````#@`````````0````?C__YZD````
M_@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#J`A3`Z@04P.V$("R@K/SLW,R\K)
MR,?&#J`!0@L````0```"//__GV`````&`````````#P```)0__^?5````F@`
M1H8.APV(#(D+B@J+"8P(C0>.!H\%1@Z@(4P.\",">@K/SLW,R\K)R,?&#J`!
M0@L````H```"D/__H7P````T`$J+"8P(C0>.!H\%1@[``E[/SLW,RPZ@`0``
M`````$0```*\__^AB````50`1HD+B@J+"8P(C0>.!H\%1@Z@(4P.R"("Y@K/
MSLW,R\K)#J`!0@M<"L_.S<S+RLD.H`%&"P```````#````,$__^BF```!8P`
M1HH*BPF,"(T'C@:/!48.T`(#!4H*S\[-S,O*#J`!1@L````````L```#./__
MI_0```!V`$R+"8P(C0>.!H\%1@[0`@)4"L_.S<S+#J`!0@L````````H```#
M:/__J#P```!X`%R&#H<-B`R)"XH*BPF,"(T'C@:/!48.Z`(``````$````.4
M__^HB````A``1H@,B0N*"HL)C`B-!XX&CP5&#`Z@@018#0]&#M""!`,!I`K/
MSLW,R\K)R`Z@`4(+````````'````]C__ZI4````+`!&C@:/!48.P`)>S\X.
MH`$```!<```#^/__JF0```$.`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.X`("
M6@K/SLW,R\K)R,?&#J`!0@M:"L_.S<S+RLG(Q\8.H`%&"P)Z"L_.S<S+RLG(
MQ\8.H`%&"P````!,```$6/__JQ0```;^`$J&#H<-B`R)"XH*BPF,"(T'C@:/
M!48.^`0#`K(*S\[-S,O*R<C'Q@Z@`4(+`P+N"L_.S<S+RLG(Q\8.H`%&"P``
M`#@```2H__^QQ````CX`1H<-B`R)"XH*BPF,"(T'C@:/!48.T`(#`<0*S\[-
MS,O*R<C'#J`!0@L``````$````3D__^SR````-(`1HD+B@J+"8P(C0>.!H\%
M1@[0`@**"L_.S<S+RLD.H`%""VX*S\[-S,O*R0Z@`48+````````/```!2C_
M_WHD```"@`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#N@"`P'`"L_.S<S+RLG(
MQ\8.H`%""P```````"````5H__^T'````&P`2HX&CP5&#L`"`EK/S@Z@`0``
M`````#P```6,__^T:````<``3(8.APV(#(D+B@J+"8P(C0>.!H\%7@[``@,!
M.@K/SLW,R\K)R,?&#J`!0@L````````\```%S/__M>@```)4`$:'#8@,B0N*
M"HL)C`B-!XX&CP5X#L`"`P$Z"L_.S<S+RLG(QPZ@`48+````````````$```
M!@S__[@`````#```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````I8````````"D8``````````$`````
M```"X0`````````!`````````NP`````````'0````````1H``````````P`
M```````>H``````````-````````9+``````````&0```````+N@````````
M`!L`````````"``````````:````````NZ@`````````'``````````(````
M``````0````````"D`````!O__[U````````!Z@`````````!0```````!%8
M``````````8````````(B``````````*````````!)P`````````"P``````
M```8`````````!4````````````````````#````````O=```````````@``
M``````4H`````````!0`````````!P`````````7````````&7@`````````
M!P```````!<@``````````@````````"6``````````)`````````!@`````
M````'@`````````(`````&____L`````"````0````!O___^````````%K``
M````;____P`````````!`````&____`````````5]`````!O___Y````````
M``X`````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````+NP
M`````````````````````````````!\.````````'RX````````?3@``````
M`!]N````````'XX````````?K@```````!_.````````'^X````````@#@``
M`````"`N````````($X````````@;@```````"".````````(*X````````@
MS@```````"#N````````(0X````````A+@```````"%.````````(6X`````
M```AC@```````"&N````````(<X````````A[@```````"(.````````(BX`
M```````B3@```````")N````````(HX````````BK@```````"+.````````
M(NX````````C#@```````",N````````(TX````````C;@```````"..````
M````(ZX````````CS@```````"/N````````)`X````````D+@```````"1.
M````````)&X````````DC@```````"2N````````),X````````D[@``````
M`"4.````````)2X````````E3@```````"5N````````)8X````````EK@``
M`````"7.````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"7@``````````````````#`"`I005(N<&T*````````````
M``````"E4````````&4\``````````````````!EW````````&7@````````
MI40```````!E0@```````*5,``````````````````"E-````````*4Z````
M``````````````!GQ$=#0SH@*%-54T4@3&EN=7@I(#$S+C$N,2`R,#(S,#<R
M,"!;<F5V:7-I;VX@.6%A8S,W86(X83=B.3$Y83@Y8S9D-C1B8S<Q,#=A.#0S
M-CDY-F4Y,UT``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI
M9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N
M=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`
M+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F
M<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD
M871A`"YB<W,`+F-O;6UE;G0`````````````````````````````````````
M``````````````````````````````````````````````````````L````!
M``````````(````````".`````````(X``````````\`````````````````
M```!```````````````3````!P`````````"`````````D@````````"2```
M```````D````````````````````!```````````````)@````<`````````
M`@````````)L`````````FP`````````(`````````````````````0`````
M`````````#@````%``````````(````````"D`````````*0````````!1@`
M```&```````````````(``````````@````T;___]@`````````"````````
M!Z@````````'J`````````#<````!@``````````````"```````````````
M/@````L``````````@````````B(````````"(@````````(T`````<````"
M``````````@`````````&````$8````#``````````(````````16```````
M`!%8````````!)P````````````````````!``````````````!.;____P``
M```````"````````%?0````````5]`````````"\````!@``````````````
M`@`````````"````6V____X``````````@```````!:P````````%K``````
M````<`````<````!``````````@``````````````&H````$``````````(`
M```````7(````````!<@`````````E@````&```````````````(````````
M`!@```!T````!`````````!"````````&7@````````9>`````````4H````
M!@```!8`````````"``````````8````?@````$`````````!@```````!Z@
M````````'J``````````0`````````````````````0``````````````'D`
M```!``````````8````````>X````````![@````````!P``````````````
M```````$`````````"````"$`````0`````````&````````)>`````````E
MX````````#[0````````````````````"```````````````B@````$`````
M````!@```````&2P````````9+``````````+`````````````````````0`
M`````````````)`````!``````````(```````!DX````````&3@````````
M0)`````````````````````(``````````````"8`````0`````````"````
M````I7````````"E<`````````#L````````````````````!```````````
M````I@````$``````````@```````*9@````````IF`````````&4```````
M``````````````@``````````````+`````.``````````,```````"[H```
M`````+N@``````````@````````````````````(``````````@```"\````
M#P`````````#````````NZ@```````"[J``````````(````````````````
M````"``````````(````R`````8``````````P```````+NP````````N[``
M```````"(`````<```````````````@`````````$````-$````!````````
M``,```````"]T````````+W0`````````C`````````````````````(````
M``````@```#6`````0`````````#````````P`````````#```````````"(
M````````````````````"```````````````W`````@``````````P``````
M`,"(````````P(@`````````*`````````````````````@`````````````
M`.$````!`````````#```````````````````,"(`````````%8`````````
M```````````!``````````$````!`````P``````````````````````````
D``#`W@````````#J`````````````````````0``````````
